==> wpewebkit_2.48.3.orig.tar.xz: wpewebkit-2.48.3/Source/WebCore/platform/graphics/filters/software/FEDisplacementMapSoftwareApplier.h <==
/*
 * Copyright (C) 2004, 2005, 2006, 2007 Nikolas Zimmermann <zimmermann@kde.org>
 * Copyright (C) 2004, 2005 Rob Buis <buis@kde.org>
 * Copyright (C) 2005 Eric Seidel <eric@webkit.org>
 * Copyright (C) 2021-2022 Apple Inc.  All rights reserved.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public License
 * along with this library; see the file COPYING.LIB.  If not, write to
 * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
 */

#pragma once

#include "FilterEffectApplier.h"
#include <wtf/TZoneMalloc.h>

namespace WebCore {

class FEDisplacementMap;

class FEDisplacementMapSoftwareApplier final : public FilterEffectConcreteApplier<FEDisplacementMap> {
    WTF_MAKE_TZONE_ALLOCATED(FEDisplacementMapSoftwareApplier);
    using Base = FilterEffectConcreteApplier<FEDisplacementMap>;

public:
    FEDisplacementMapSoftwareApplier(const FEDisplacementMap&);

private:
    bool apply(const Filter&, const FilterImageVector& inputs, FilterImage& result) const final;

    static inline unsigned byteOffsetOfPixel(unsigned x, unsigned y, unsigned rowBytes)
    {
        const unsigned bytesPerPixel = 4;
        return x * bytesPerPixel + y * rowBytes;
    }

    int xChannelIndex() const;
    int yChannelIndex() const;
};

} // namespace WebCore

==> wpewebkit_2.50.5.orig.tar.xz: wpewebkit-2.50.5/Source/WebCore/platform/graphics/filters/software/FEDisplacementMapSoftwareApplier.h <==
/*
 * Copyright (C) 2004, 2005, 2006, 2007 Nikolas Zimmermann <zimmermann@kde.org>
 * Copyright (C) 2004, 2005 Rob Buis <buis@kde.org>
 * Copyright (C) 2005 Eric Seidel <eric@webkit.org>
 * Copyright (C) 2021-2022 Apple Inc. All rights reserved.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public License
 * along with this library; see the file COPYING.LIB.  If not, write to
 * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
 */

#pragma once

#include "FilterEffectApplier.h"
#include <wtf/TZoneMalloc.h>

namespace WebCore {

class FEDisplacementMap;

class FEDisplacementMapSoftwareApplier final : public FilterEffectConcreteApplier<FEDisplacementMap> {
    WTF_MAKE_TZONE_ALLOCATED(FEDisplacementMapSoftwareApplier);
    using Base = FilterEffectConcreteApplier<FEDisplacementMap>;

public:
    FEDisplacementMapSoftwareApplier(const FEDisplacementMap&);

private:
    bool apply(const Filter&, std::span<const Ref<FilterImage>> inputs, FilterImage& result) const final;

    static inline unsigned byteOffsetOfPixel(unsigned x, unsigned y, unsigned rowBytes)
    {
        const unsigned bytesPerPixel = 4;
        return x * bytesPerPixel + y * rowBytes;
    }

    int xChannelIndex() const;
    int yChannelIndex() const;
};

} // namespace WebCore
